@@ -398,3 +398,219 @@ table.dlsip     {
 .search_highlight {
 	color: #ff6600;
 }
+
+.def_HorzCross {
+    color: #000000;
+    background-color: #313b30;
+}
+
+.def_VertCross {
+    color: #000000;
+    background-color: #313b30;
+}
+
+.def_Number {
+    color: #00a800;
+}
+
+.def_NumberDec {
+    color: #008c00;
+}
+
+.def_NumHex {
+    color: #008000;
+}
+
+.def_NumberBin {
+    color: #007d00;
+}
+
+.def_NumberOct {
+    color: #008c00;
+}
+
+.def_NumberFloat {
+    color: #009f00;
+}
+
+.def_NumberSuffix {
+    color: #006600;
+}
+
+.def_String {
+    color: #00c4c4;
+}
+
+.def_Special {
+    color: #008B8B;
+}
+
+.def_StringContent {
+    color: #008080;
+}
+
+.def_StringEdge {
+    color: #02d045;
+}
+
+.def_CharacterContent {
+    color: #008080;
+}
+
+.def_Comment {
+    color: #9999a9;
+}
+
+.def_CommentContent {
+    color: #8695b8;
+    font-weight: bold;
+}
+
+.def_CommentDoc {
+    color: #90b0e0;
+}
+
+.def_SymbolStrong {
+    color: #b060b0;
+}
+
+.def_Prefix {
+    color: #00dddd;
+}
+
+.def_Operator {
+    color: #00dddd;
+}
+
+.def_Keyword {
+    color: #A52A2A;
+    font-weight: bold;
+}
+
+.def_KeywordStrong {
+    color: #904050;
+}
+
+.def_ClassKeyword {
+    color: #bb7977;
+    font-weight: bold;
+}
+
+.def_TypeKeyword {
+    color: #bb7977;
+}
+
+.def_Register {
+    color: #d0d09f;
+}
+
+.def_Constant {
+    color: #007d45;
+}
+
+.def_BooleanConstant {
+    color: #0f4d75;
+}
+
+.def_Var {
+    color: #007997;
+}
+
+.def_VarStrong {
+    color: #007997;
+}
+
+.def_Identifier {
+    color: #005fd2;
+}
+
+.def_Directive {
+    color: #008073;
+}
+
+.def_Param {
+    color: #64810c;
+}
+
+.def_Tag {
+    color: #f6c1d0;
+}
+
+.def_OpenTag {
+    color: #ff8906;
+}
+
+.def_CloseTag {
+    color: #fb8400;
+}
+
+.def_Label {
+    color: #e34adc;
+}
+
+.def_LabelStrong {
+    color: #000000;
+    background-color: #a8a800;
+}
+
+.def_Insertion {
+    color: #ffffff;
+    background-color: #281800;
+}
+
+.def_InsertionStart {
+    color: #800000;
+    background-color: #ffffa4;
+}
+
+.def_InsertionEnd {
+    color: #800000;
+    background-color: #ffffa4;
+}
+
+.def_Error {
+    color: #ffffff;
+    background-color: #dd0000;
+}
+
+.def_ErrorText {
+    color: #ee00ee;
+}
+
+.def_TODO {
+    color: #ffffff;
+    background-color: #3c215f;
+}
+
+.def_Debug {
+    color: #011a47;
+    background-color: #007084;
+}
+
+.def_Path {
+    color: #40015a;
+}
+
+.def_URL {
+    color: #6070ec;
+}
+
+.def_EMail {
+    color: #a160f4;
+}
+
+.def_Date {
+    color: #009797;
+}
+
+.def_Time {
+    color: #8745a0;
+}
+
+.def_PairStart {
+    color: #aa4444;
+}
+
+.def_PairEnd {
+    color: #aa4444;
+}
